# based on the spec file from https://build.opensuse.org/package/view_file/home:Simmphonie/libx265/

Name:           x265
%define soname  59
%define libname lib%{name}
%define libsoname %{libname}-%{soname}
Version:        1.7
Release:        1.1
License:        GPL-2.0+
Summary:        A free h265/HEVC encoder - encoder binary
Url:            https://bitbucket.org/multicoreware/x265/wiki/Home
Group:          Productivity/Multimedia/Video/Editors and Convertors
Source0:        https://bitbucket.org/multicoreware/x265/downloads/%{name}_%{version}.tar.gz
Patch0:         arm.patch
BuildRequires:  gcc gcc-c++
BuildRequires:  cmake >= 2.8.8
BuildRequires:  pkg-config
BuildRequires:  yasm >= 1.2.0
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
x265 is a free library for encoding next-generation H265/HEVC video
streams.

%package -n %{libsoname}
Summary:        A free H265/HEVC encoder - encoder binary
Group:          Productivity/Multimedia/Video/Editors and Convertors

%description -n %{libsoname}
x265 is a free library for encoding next-generation H265/HEVC video
streams.

%package -n %{libname}-devel
Summary:        Libraries and include file for the %{libname} encoder
Group:          Development/Libraries/C and C++
Requires:       %{buildrequires}
Requires:       %{libsoname} = %{version}
Provides:       %{name}-devel = %{version}
Obsoletes:      %{name}-devel < %{version}

%description -n %{libname}-devel
x265 is a free library for encoding next-generation H265/HEVC video
streams. 

%prep
%setup -q -n "%{name}_%{version}/build/linux"
cd ../..
%patch0
cd -
%define FAKE_BUILDDATE %(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes '+%%b %%e %%Y')
sed -i -e "s/0.0/%{soname}.0/g" ../../source/cmake/version.cmake


%build
export CXXFLAGS="%optflags"
export CFLAGS="%optflags"
cmake  -DCMAKE_INSTALL_PREFIX=/usr -DENABLE_TESTS=ON -G "Unix Makefiles" ../../source
cmake -DCMAKE_INSTALL_PREFIX=/usr ../../source
#./make-Makefiles.bash
make %{?_smp_mflags} VERBOSE=1

%install
%makeinstall
%ifarch x86_64
  mv "%{buildroot}/usr/lib" "%{buildroot}%{_libdir}"
%endif

rm -f %{buildroot}%{_libdir}/%{libname}.a

echo "%{libname}-%{soname}" > %{_sourcedir}/baselibs.conf

%clean
%{?buildroot:%__rm -rf "%{buildroot}"}

%post -n %{libsoname} -p /sbin/ldconfig
%postun -n %{libsoname} -p /sbin/ldconfig

%files -n %{libsoname}
%defattr(0644,root,root)
%{_libdir}/%{libname}.so.%{soname}*

%files 
%defattr(0755,root,root)
%{_bindir}/%{name}

%files -n %{libname}-devel
%defattr(0644,root,root)
%{_includedir}/%{name}.h
%{_includedir}/%{name}_config.h
%{_libdir}/pkgconfig/%{name}.pc
%{_libdir}/%{libname}.so

%changelog
* Fri May 29 2015 aloisio@gmx.com
- soname bump to 59
- Update to version 1.7
  * large amount of assembly code optimizations
  * some preliminary support for high dynamic range content
  * improvements for multi-library support
  * some new quality features
    (full documentation at: http://x265.readthedocs.org/en/1.7)
  * This release simplifies the multi-library support introduced
    in version 1.6. Any libx265 can now forward API requests to
    other installed libx265 libraries (by name) so applications
    like ffmpeg and the x265 CLI can select between 8bit and 10bit
    encodes at runtime without the need of a shim library or
    library load path hacks. See --output-depth, and
    http://x265.readthedocs.org/en/1.7/api.html#multi-library-interface
  * For quality, x265 now allows you to configure the quantization
    group size smaller than the CTU size (for finer grained AQ
    adjustments). See --qg-size.
  * x265 now supports limited mid-encode reconfigure via a new public
    method: x265_encoder_reconfig()
  * For HDR, x265 now supports signaling the SMPTE 2084 color transfer
    function, the SMPTE 2086 mastering display color primaries, and the
    content light levels. See --master-display, --max-cll
  * x265 will no longer emit any non-conformant bitstreams unless
  - -allow-non-conformance is specified.
  * The x265 CLI now supports a simple encode preview feature. See
  - -recon-y4m-exec.
  * The AnnexB NAL headers can now be configured off, via x265_param.bAnnexB
    This is not configurable via the CLI because it is a function of the
    muxer being used, and the CLI only supports raw output files. See
  - -annexb
  Misc:
  * --lossless encodes are now signaled as level 8.5
  * --profile now has a -P short option
  * The regression scripts used by x265 are now public, and can be found at:
    https://bitbucket.org/sborho/test-harness
  * x265's cmake scripts now support PGO builds, the test-harness can be
    used to drive the profile-guided build process.
* Tue Apr 28 2015 aloisio@gmx.com
- soname bumped to 51
- Update to stable version 1.6
  Perfomance changes:
  * heavy improvements for AVX2 capable platforms
    (Haswell and later Intel CPUs) and work efficiency
    improvements for multiple-socket machines.
  API changes:
  * --threads N replaced by --pools N,N and --lookahead-slices N
  * --[no-]rdoq-level N - finer control over RDOQ effort
  * --min-cu-size N - trade-off compression for performance
  * --max-tu-size N - trade-off compression for performance
  * --[no-]temporal-layers - code unreferenced B frames in temporal
    layer 1
  * --[no-]cip aliases added for --[no-]constrained-intra
  * Added support for new color transfer functions "smpte-st-2084"
    and "smpte-st-428
  * --limit-refs N was added, but not yet implemented
  * Deprecated x265_setup_primitives() was removed from the public
    API and is no longer exported DLLs
  Threading changes:
  * The x265 thread pool has been made NUMA aware.
  * The --threads  parameter, which used to specify a global
    pool size, has been replaced with a --pools parameter which
    allows you to specify a pool size per NUMA node (aka CPU socket
    or package). The default is still to allocate one pool worker
    thread per logical core on the machine, but with --pools one
    can isolate those threads to a given socket.
  * Other than socket isolation, the biggest visible change in the
    NUMA aware thread pools is the increase in work efficiency.
    The total utilization will generally decrease but the performance
    will increase since worker threads spend less time context
    switching.  Also, the threading of the lookahead was made more
    work-efficient. Each lookahead job is a much larger piece of work.
    Before (1.5):
    disable thread pool: --threads 1
    default thread pool: --threads 0
    restrict to 4 threads: --threads 4
    After (1.6):
    disable thread pools: --pools 0
    default thread pools: --pools *
    restrict to 4 threads: --pools 4
    restrict to 4 threads on socket 1: --pools -,4
    restrict to all threads on socket 0: --pools +,-
  Multi-lib interface:
  * In order to support runtime selection of a libx265
    shared library, we have introduced an x265_api structure
    and an x265_api_get() function. Applications which use
    this interface to acquire the libx265 functional interface
    will be able to use shim libraries to bind a particular build
    of libx265 at run time. See the API documentation for full
    details.
* Sun Feb 22 2015 aloisio@gmx.com
- soname bump
- Update to stable version 1.5
  * improvements in Main10 compression efficiency and performance
    and psycho-visual optimizations now enabled by default
  Feature additions:
  * analysis re-use features have been completed
  * rate control zones have been introduced
  * --tune grain introduced
  * deblocking tC and Beta offsets are now configurable
  * denoise is seperately configurable for inter and intra CUs
  * frame based CSV logging has been improved
  * New support for VTune task profiles
  Presets and defaults:
  * ultrafast no longer disables the deblocking loop filter
  * psy-rd defaults to 0.3   (was 0, disabled)
  * psy-rdoq defaults to 1.0 (was 0, disabled)
  * aq-mode defaults to 1    (was 2, auto-variance)
  * 4:2:2 and 4:4:4 encodes no longer generate compliance warnings
  API changes:
  * param.rc.rateTolerance has been removed and replaced with a simpler
    param.rc.bStrictCbr flag.
  * --log-level debug is now --log-level 4 instead of --log-level 3.
    A new 'frame' log level was inserted at level 3 in order to support
    frame level CSV logging without also enabling frame level console
    logging. Using the string name 'debug' is unambiguous as its
    behavior has not changed.
- version 1.4
  * large refactoring in the analysis code
  Feature additions:
  * --pmode (parallel mode decision)
  * --pme (parallel motion estimation).
  Presets and defaults:
  * --amp is now respected in RD levels 2, 3, and 4 (previously only
    in 5 and 6).
  * --b-intra is now respected in all RD levels.
  * --fast-cbf, which has only ever effective at RD levels 5 and 6,
    is no longer enabled uselessly in the fastest presets.
  * --weightb is now enabled by default at presets slower, veryslow,
    and placebo.
  * --cu-lossless was changed to only attempt a lossless encode of
    the best lossy encode method. This made --cu-lossless a much less
    expensive encode option to have enabled, and hopefully made the
    feature more robust and maintainable.
  * The upper threshold for --psy-rdoq was raised to 50 (from 10)
    since the higher values were found to be beneficial for sources
    with high frequency noise (film grain).
  * The default thread pool size logic was updated to account for the
    addition of --pmode and --pme (if WPP is disabled but --pmode or
  - -pme are enabled, a thread pool is still allocated).
* Mon Dec  8 2014 crrodriguez@opensuse.org
- Ensure we use the proper CXXFLAGS, CFLAGS and therefore
  debuginfo packages are generated correctly.
* Sat Oct  4 2014 aloisio@gmx.com
- Bumped to version hg20140928
* Thu Jun  5 2014 guillaume@opensuse.org
- Fix ARM build with arm.patch from Arch Linux:
  https://github.com/archlinuxarm/PKGBUILDs/blob/master/extra/x265/arm.patch
* Thu May  8 2014 Manfred.Tremmel@iiv.de
- added baselibs.conf
* Mon Mar 24 2014 Manfred.Tremmel@iiv.de
- initial build of todays mercurial checkout
